# Community Contributions!

Here you can see notebooks created by community members which demonstrate
capabilities of AstroPhot and may also inspire you for your analysis!

Submit your notebook to [Connor Stone](connorstone628@gmail.com) to get added!

## Time Variable SN Models

This one is by [Michael Wood-Vasey](https://github.com/wmwv) and demonstrates a
simultaneous fit of a supernova across multiple epochs.

[Mock Roman SN data](https://github.com/Autostronomy/AstroPhot-tutorials/blob/main/tutorials/TimeVariableModels_DC2_11392192729110.ipynb)

[Mock Rubin SN data v1](https://github.com/Autostronomy/AstroPhot-tutorials/blob/main/tutorials/TimeVariableModels_DC2_11392192729110.ipynb)

[Mock Rubin SN data v2](https://github.com/Autostronomy/AstroPhot-tutorials/blob/main/tutorials/TimeVariableModels_DC2_41021613806.ipynb)
